searchData={"items":[{"type":"task","doc":"Generate VAPID keys for config.\n\nExample:\n\n    $ mix web_push.vapid","title":"mix web_push_ex.vapid","ref":"Mix.Tasks.WebPushEx.Vapid.html"},{"type":"module","doc":"Web Push notifications via `aes128gcm`.\n\nImplementation of RFC 8291, 8188, & 5689.","title":"WebPushEx","ref":"WebPushEx.html"},{"type":"function","doc":"Decode a URL-safe Base64-encoded string with @base64_options (padding: false).","title":"WebPushEx.decode/1","ref":"WebPushEx.html#decode/1"},{"type":"function","doc":"URL-safe Base64 encode a binary with @base64_options (padding: false).","title":"WebPushEx.encode/1","ref":"WebPushEx.html#encode/1"},{"type":"function","doc":"Encrypt a message according to RFCs 8291, 8188, 5869.\n\nsee: https://datatracker.ietf.org/doc/html/rfc8291/#section-3.1","title":"WebPushEx.encrypt_payload/3","ref":"WebPushEx.html#encrypt_payload/3"},{"type":"function","doc":"Build and return a Request struct with details ready for sending.","title":"WebPushEx.request/3","ref":"WebPushEx.html#request/3"},{"type":"type","doc":"","title":"WebPushEx.info/0","ref":"WebPushEx.html#t:info/0"},{"type":"type","doc":"","title":"WebPushEx.input_keying_material/0","ref":"WebPushEx.html#t:input_keying_material/0"},{"type":"type","doc":"","title":"WebPushEx.key/0","ref":"WebPushEx.html#t:key/0"},{"type":"type","doc":"","title":"WebPushEx.length/0","ref":"WebPushEx.html#t:length/0"},{"type":"type","doc":"","title":"WebPushEx.psuedo_random_key/0","ref":"WebPushEx.html#t:psuedo_random_key/0"},{"type":"type","doc":"","title":"WebPushEx.salt/0","ref":"WebPushEx.html#t:salt/0"},{"type":"type","doc":"","title":"WebPushEx.vapid_key/0","ref":"WebPushEx.html#t:vapid_key/0"},{"type":"module","doc":":json wrapper for JOSE.","title":"WebPushEx.JOSEjson","ref":"WebPushEx.JOSEjson.html"},{"type":"module","doc":"Request details ready for sending to the subscription endpoint.","title":"WebPushEx.Request","ref":"WebPushEx.Request.html"},{"type":"type","doc":"Encrypted Content Encoding body.","title":"WebPushEx.Request.body/0","ref":"WebPushEx.Request.html#t:body/0"},{"type":"type","doc":"`URI` to send the POST request to.","title":"WebPushEx.Request.endpoint/0","ref":"WebPushEx.Request.html#t:endpoint/0"},{"type":"type","doc":"`Map` of headers to include with the POST request.","title":"WebPushEx.Request.headers/0","ref":"WebPushEx.Request.html#t:headers/0"},{"type":"type","doc":"","title":"WebPushEx.Request.t/0","ref":"WebPushEx.Request.html#t:t/0"},{"type":"module","doc":"Subscription data structure.","title":"WebPushEx.Subscription","ref":"WebPushEx.Subscription.html"},{"type":"function","doc":"Build and return a new struct from a JSON string.","title":"WebPushEx.Subscription.from_json/1","ref":"WebPushEx.Subscription.html#from_json/1"},{"type":"type","doc":"Matching structure returned from User Agents with JSON import/export functions.","title":"WebPushEx.Subscription.t/0","ref":"WebPushEx.Subscription.html#t:t/0"},{"type":"extras","doc":"# WebPushEx\n\nThis library implements\n[RFC 8291](https://datatracker.ietf.org/doc/html/rfc8291/) Message Encryption\nfor Web Push in Elixir.\n\nIt generates request details but does not make the HTTP POST request itself. The\ngenerated details should be enough to feed to your HTTP client of choice.\n\n#### Features\n\n* `aes128gcm` content encoding method\n* uses `:json` (requires Erlang/OTP >=27)\n* uses JOSE for handling JWT\n* bring your own HTTP client\n* tested using RFC examples","title":"WebPushEx","ref":"readme.html"},{"type":"extras","doc":"`WebPush` needs VAPID keys to work. Run `mix web_push.vapid` and adapt the\ngenerated config to your needs:\n\n```\n$ mix web_push.vapid\n# in config/config.exs:\n\n    config :web_push_ex, :vapid,\n      public_key: \" \"\n      subject: \"webpush-admin-email@example.com\"\n\n# in config/runtime.exs:\n\n    config :web_push_ex, :vapid,\n      private_key: System.fetch_env!(\"WEB_PUSH_VAPID_PRIVATE_KEY\")\n\n# in your environment:\n\n    export WEB_PUSH_EX_VAPID_PRIVATE_KEY= \n```","title":"Configuration - WebPushEx","ref":"readme.html#configuration"},{"type":"extras","doc":"Your application should handle getting and persisting subscription data from\nbrowsers. The implementation is up to you but the VAPID public key is required\nto be presented when calling `pushManager.subscribe()`:\n\n```javascript\npushManager.subscribe({\n  userVisibleOnly: true,\n  applicationServerKey: vapidPublicKey,\n}).then(...);\n```\n\nOnce you have your subscription data, you may construct a `WebPushEx.Request` and\nuse it to make the push notification via the HTTP client of your choice.\n\n```elixir\n# create the struct from the subscription JSON data\nsubscription =\n  WebPushEx.Subscription.from_json(\"\"\"\n  {\"endpoint\":\"https://push.example.com/123\",\"keys\":{\"p256dh\":\"user_agent_public_key\",\"auth\":\"auth_secret\"}}\n  \"\"\")\n\n# structured message, see example serviceWorker.js linked below\nmessage = %{title: \"Notification Title\", body: \"lorem ipsum etc\"}\n\n# generate request details\n%WebPushEx.Request{} = request = WebPushEx.request(subscription, :json.encode(message) |> to_string())\n\nrequest.endpoint\n# => \"https://push.example.com/123\"\n\nrequest.body\n# => binary data\n\nrequest.headers\n# => %{\n#   \"Authorization\" => \"vapid t=..., k=...\",\n#   \"Content-Encoding\" => \"aes128gcm\",\n#   \"Content-Length\" => \"42\",\n#   \"Content-Type\" => \"application/octet-stream\",\n#   \"TTL\" => \"43200\",\n#   \"Urgency\" => \"normal\"\n# }\n\n# send web push notification via http client e.g. req\n{:ok, resp} = Req.post(request.endpoint, body: request.body, headers: request.headers)\n```","title":"Usage - WebPushEx","ref":"readme.html#usage"},{"type":"extras","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `web_push` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:web_push_ex, \"~> 0.1.0\"}\n  ]\nend\n```","title":"Installation - WebPushEx","ref":"readme.html#installation"},{"type":"extras","doc":"#### Motivation && Inspiration\n\nMany thanks to maintainers and contributors to all these repos 🙇\n\n* [web-push-elixir](https://github.com/midarrlabs/web-push-elixir)\n* [web-push-encryption](https://github.com/tuvistavie/elixir-web-push-encryption)\n* [web-push](https://github.com/web-push-libs/web-push)\n* [erl_web_push](https://github.com/truqu/erl_web_push)\n\n#### Useful Links\n\n* https://datatracker.ietf.org/doc/html/rfc8291/\n* https://datatracker.ietf.org/doc/html/rfc8188/\n* https://datatracker.ietf.org/doc/html/rfc3279/\n\n* https://mozilla-services.github.io/WebPushDataTestPage/\n* https://developer.mozilla.org/en-US/docs/Web/API/Push_API\n* https://developer.mozilla.org/en-US/docs/Web/API/Service_Worker_API/Using_Service_Workers\n* https://github.com/mdn/serviceworker-cookbook/tree/master/push-payload\n* https://blog.mozilla.org/services/2016/08/23/sending-vapid-identified-webpush-notifications-via-mozillas-push-service/\n* https://hacks.mozilla.org/2017/05/debugging-web-push-in-mozilla-firefox/\n\n* https://developer.apple.com/documentation/usernotifications/sending-web-push-notifications-in-web-apps-and-browsers","title":"tl() - WebPushEx","ref":"readme.html#tl"},{"type":"extras","doc":"","title":"CHANGELOG","ref":"changelog.html"},{"type":"extras","doc":"* [#3](https://github.com/kenichi/web-push-ex/pull/3) - refactor out `String.to_existing_atom/1` (thanks @speeddragon!)\n* [#1](https://github.com/kenichi/web-push-ex/pull/1) - fix example in README (thanks @speeddragon!)","title":"0.2.0 - CHANGELOG","ref":"changelog.html#0-2-0"},{"type":"extras","doc":"* initial release\n* basic aes128gcm functionality\n* supports browsers, desktop and mobile:\n    * apple safari\n    * google chrome\n    * mozilla firefox","title":"0.1.0 - CHANGELOG","ref":"changelog.html#0-1-0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}